==> HTML-Menu-TreeView-0.6.3.tar.gz: HTML-Menu-TreeView-0.6.3/htdocs/style/Crystal/128/html-menu-treeview/preload.js <==
folderClosed = new Image(128,128);
folderClosed.src='/style/Crystal/128/html-menu-treeview/folderClosed.gif';
plusNodeClosed = new Image(128,128);
plusNodeClosed.src='/style/Crystal/128/html-menu-treeview/plusNodeClosed.gif';
lastPlusNodeClosed = new Image(128,128);
lastPlusNodeClosed.src='/style/Crystal/128/html-menu-treeview/lastPlusNodeClosed.gif';
clasicPlusNodeClosed = new Image(128,128);
clasicPlusNodeClosed.src='/style/Crystal/128/html-menu-treeview/clasicPlusNodeClosed.gif';
clasicLastPlusNodeClosed = new Image(128,128);
clasicLastPlusNodeClosed.src='/style/Crystal/128/html-menu-treeview/clasicLastPlusNodeClosed.gif';
folderManClosed = new Image(128,128);
folderManClosed.src='/style/Crystal/128/html-menu-treeview/folderManClosed.gif';
folderGray = new Image(128,128);
folderGray.src='/style/Crystal/128/html-menu-treeview/folderGray.gif';
folderGreen = new Image(128,128);
folderGreen.src='/style/Crystal/128/html-menu-treeview/folderGreen.gif';
folderViolet = new Image(128,128);
folderViolet.src='/style/Crystal/128/html-menu-treeview/folderViolet.gif';
folderYellowClosed = new Image(128,128);
folderYellowClosed.src='/style/Crystal/128/html-menu-treeview/folderYellowClosed.gif';
folderOrangeClosed = new Image(128,128);
folderOrangeClosed.src='/style/Crystal/128/html-menu-treeview/folderOrangeClosed.gif';
folderManClosed = new Image(128,128);
folderManClosed.src='/style/Crystal/128/html-menu-treeview/folderManClosed.gif';
folderHtmlClosed = new Image(128,128);
folderHtmlClosed.src='/style/Crystal/128/html-menu-treeview/folderHtmlClosed.gif';
folderFavoriteClosed = new Image(128,128);
folderFavoriteClosed.src='/style/Crystal/128/html-menu-treeview/folderFavoriteClosed.gif';
folderTextClosed = new Image(128,128);
folderTextClosed.src='/style/Crystal/128/html-menu-treeview/folderTextClosed.gif';
folderLockedClosed = new Image(128,128);
folderLockedClosed.src='/style/Crystal/128/html-menu-treeview/folderLockedClosed.gif';
folderCrystalClosed = new Image(128,128);
folderCrystalClosed.src='/style/Crystal/128/html-menu-treeview/folderCrystalClosed.gif';
folderVideoClosed = new Image(128,128);
folderVideoClosed.src='/style/Crystal/128/html-menu-treeview/folderVideoClosed.gif';
folderPrintClosed = new Image(128,128);
folderPrintClosed.src='/style/Crystal/128/html-menu-treeview/folderPrintClosed.gif';
folderImageClosed = new Image(128,128);
folderImageClosed.src='/style/Crystal/128/html-menu-treeview/folderImageClosed.gif';
folderSoundClosed = new Image(128,128);
folderSoundClosed.src='/style/Crystal/128/html-menu-treeview/folderSoundClosed.gif';
folderImportantClosed = new Image(128,128);
folderImportantClosed.src='/style/Crystal/128/html-menu-treeview/folderImportantClosed.gif';
folderTarClosed = new Image(128,128);
folderTarClosed.src='/style/Crystal/128/html-menu-treeview/folderTarClosed.gif';

==> HTML-Menu-TreeView-0.6.5.tar.gz: HTML-Menu-TreeView-0.6.5/htdocs/style/Crystal/128/html-menu-treeview/preload.js <==
folderClosed = new Image(128,128);
folderClosed.src='/style/Crystal/128/html-menu-treeview/folderClosed.gif';
plusNode = new Image(128,128);
plusNode.src='/style/Crystal/128/html-menu-treeview/plusNode.gif';
lastplusNode = new Image(128,128);
lastplusNode.src='/style/Crystal/128/html-menu-treeview/lastplusNode.gif';
clasicplusNode = new Image(128,128);
clasicplusNode.src='/style/Crystal/128/html-menu-treeview/clasicplusNode.gif';
clasicLastplusNode = new Image(128,128);
clasicLastplusNode.src='/style/Crystal/128/html-menu-treeview/clasicLastplusNode.gif';
folderManClosed = new Image(128,128);
folderManClosed.src='/style/Crystal/128/html-menu-treeview/folderManClosed.gif';
folderGray = new Image(128,128);
folderGray.src='/style/Crystal/128/html-menu-treeview/folderGray.gif';
folderGreen = new Image(128,128);
folderGreen.src='/style/Crystal/128/html-menu-treeview/folderGreen.gif';
folderViolet = new Image(128,128);
folderViolet.src='/style/Crystal/128/html-menu-treeview/folderViolet.gif';
folderYellowClosed = new Image(128,128);
folderYellowClosed.src='/style/Crystal/128/html-menu-treeview/folderYellowClosed.gif';
folderOrangeClosed = new Image(128,128);
folderOrangeClosed.src='/style/Crystal/128/html-menu-treeview/folderOrangeClosed.gif';
folderManClosed = new Image(128,128);
folderManClosed.src='/style/Crystal/128/html-menu-treeview/folderManClosed.gif';
folderHtmlClosed = new Image(128,128);
folderHtmlClosed.src='/style/Crystal/128/html-menu-treeview/folderHtmlClosed.gif';
folderFavoriteClosed = new Image(128,128);
folderFavoriteClosed.src='/style/Crystal/128/html-menu-treeview/folderFavoriteClosed.gif';
folderTextClosed = new Image(128,128);
folderTextClosed.src='/style/Crystal/128/html-menu-treeview/folderTextClosed.gif';
folderLockedClosed = new Image(128,128);
folderLockedClosed.src='/style/Crystal/128/html-menu-treeview/folderLockedClosed.gif';
folderCrystalClosed = new Image(128,128);
folderCrystalClosed.src='/style/Crystal/128/html-menu-treeview/folderCrystalClosed.gif';
folderVideoClosed = new Image(128,128);
folderVideoClosed.src='/style/Crystal/128/html-menu-treeview/folderVideoClosed.gif';
folderPrintClosed = new Image(128,128);
folderPrintClosed.src='/style/Crystal/128/html-menu-treeview/folderPrintClosed.gif';
folderImageClosed = new Image(128,128);
folderImageClosed.src='/style/Crystal/128/html-menu-treeview/folderImageClosed.gif';
folderSoundClosed = new Image(128,128);
folderSoundClosed.src='/style/Crystal/128/html-menu-treeview/folderSoundClosed.gif';
folderImportantClosed = new Image(128,128);
folderImportantClosed.src='/style/Crystal/128/html-menu-treeview/folderImportantClosed.gif';
folderTarClosed = new Image(128,128);
folderTarClosed.src='/style/Crystal/128/html-menu-treeview/folderTarClosed.gif';
